## 上证E互动

接口：irm_qa_sh，历史数据开始于2023年6月。

描述：获取上交所e互动董秘问答文本数据。上证e互动是由上海证券交易所建立、上海证券市场所有参与主体无偿使用的沟通平台,旨在引导和促进上市公司、投资者等各市场参与主体之间的信息沟通,构建集中、便捷的互动渠道。本接口数据记录了以上沟通问答的文本数据。

限量：单次请求最大返回3000行数据，可根据股票代码，日期等参数循环提取全部数据

权限：用户后120积分可以试用，正式权限为10000积分，或申请单独开权限，请参考权限说明

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码 |
| trade_date | str | N | 交易日期（格式YYYYMMDD，下同） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |
| pub_date | str | N | 发布开始日期(格式：2025-06-03 16:43:03) |
| pub_date | str | N | 发布结束日期(格式：2025-06-03 18:43:23) |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| name | str | Y | 公司名称 |
| trade_date | str | Y | 日期 |
| q | str | Y | 问题 |
| a | str | Y | 回复 |
| pub_time | datetime | Y | 回复时间 |

接口调用

```python
pro = ts.pro_api()

#获取2025年2月12日上证e互动的问答文本
df = pro.irm_qa_sh(ann_date='20250212')
```

数据样例

```python
ts_code  name                                                  q                                                  a
0   601121.SH  宝地矿业  股价利多因素主要看基本面，关键是业绩，利空因素就是减持和低价增发，目前宝地的业绩难以抵消股东...  尊敬的投资者，您好！衷心感谢您对宝地矿业的关注与鞭策。公司将加快推进重点项目建设，做好生产经...
```